@@ -1,6 +1,5 @@
 #!/usr/local/bin/python3.12
 ###############################################################################
-# $Id$
 #
 #  Project:  GDAL samples
 #  Purpose:  Delete a virtual file
@@ -65,7 +64,7 @@ def gdal_rm(argv, progress=None):
 
     argv = gdal.GeneralCmdLineProcessor(argv)
     if argv is None:
-        return -1
+        return 0
 
     for i in range(1, len(argv)):
         if not argv[i]:
