@@ -1,7 +1,6 @@
 #!/usr/local/bin/python3.12
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id$
 #
 #  Project:  GDAL
 #  Purpose:  Validate JPEG2000 file structure
@@ -191,7 +190,7 @@ def get_gmljp2(filename):
     return mdd[0]
 
 
-class ErrorReport(object):
+class ErrorReport:
     def __init__(self, collect_internally=False):
         self.error_count = 0
         self.warning_count = 0
